@@ -768,7 +768,9 @@ static int
 cmd_cycle (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	char *key = sess->channelkey;
-	char *chan = sess->channel;
+	char *chan = word[2];
+	if (!*chan)
+		chan = sess->channel;
 	if (*chan && sess->type == SESS_CHANNEL)
 	{
 		sess->server->p_cycle (sess->server, chan, key);
@@ -1182,10 +1184,10 @@ menu_del (char *path, char *label)
 static char
 menu_is_mainmenu_root (char *path, gint16 *offset)
 {
-	static const char *menus[] = {"\x4$TAB","\x5$TRAY","\x4$URL","\x5$NICK"};
+	static const char *menus[] = {"\x4$TAB","\x5$TRAY","\x4$URL","\x5$NICK","\x5$CHAN"};
 	int i;
 
-	for (i = 0; i < 4; i++)
+	for (i = 0; i < 5; i++)
 	{
 		if (!strncmp (path, menus[i] + 1, menus[i][0]))
 		{
@@ -2971,13 +2973,8 @@ cmd_settab (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 static int
 cmd_settext (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
-	if (*word_eol[2])
-	{
-		fe_set_inputbox_contents (sess, word_eol[2]);
-		return TRUE;
-	}
-
-	return FALSE;
+	fe_set_inputbox_contents (sess, word_eol[2]);
+	return TRUE;
 }
 
 static int
@@ -3536,7 +3533,7 @@ const struct commands xc_cmds[] = {
 	{"CTCP", cmd_ctcp, 1, 0, 1,
 	 N_("CTCP <nick> <message>, send the CTCP message to nick, common messages are VERSION and USERINFO")},
 	{"CYCLE", cmd_cycle, 1, 1, 1,
-	 N_("CYCLE, parts current channel and immediately rejoins")},
+	 N_("CYCLE [<channel>], parts the current or given channel and immediately rejoins")},
 	{"DCC", cmd_dcc, 0, 0, 1,
 	 N_("\n"
 	 "DCC GET <nick>                      - accept an offered file\n"
@@ -3673,7 +3670,7 @@ const struct commands xc_cmds[] = {
 	{"SERVER", cmd_server, 0, 0, 1,
 	 N_("SERVER <host> [<port>] [<password>], connects to a server, the default port is 6667")},
 #endif
-	{"SET", cmd_set, 0, 0, 1, N_("SET [-e] [-quiet] <variable> [<value>]")},
+	{"SET", cmd_set, 0, 0, 1, N_("SET [-e] [-or] [-quiet] <variable> [<value>]")},
 	{"SETCURSOR", cmd_setcursor, 0, 0, 1, N_("SETCURSOR [-|+]<position>")},
 	{"SETTAB", cmd_settab, 0, 0, 1, 0},
 	{"SETTEXT", cmd_settext, 0, 0, 1, 0},
