@@ -1831,6 +1831,10 @@ server_set_defaults (server *serv)
 	serv->supports_watch = FALSE;
 	serv->bad_prefix = FALSE;
 	serv->use_who = TRUE;
+	serv->have_namesx = FALSE;
+	serv->have_uhnames = FALSE;
+	serv->have_whox = FALSE;
+	serv->have_capab = FALSE;
 	serv->have_idmsg = FALSE;
 	serv->have_except = FALSE;
 }
