@@ -334,6 +334,7 @@ session_new (server *serv, char *from, int type, int focus)
 
 	sess->server = serv;
 	sess->logfd = -1;
+	sess->scrollfd = -1;
 	sess->type = type;
 	sess->hide_join_part = prefs.confmode;
 
@@ -357,15 +358,9 @@ new_ircwindow (server *serv, char *name, int type, int focus)
 	case SESS_SERVER:
 		serv = server_new ();
 		if (prefs.use_server_tab)
-		{
-			register unsigned int oldh = prefs.hideuserlist;
-			prefs.hideuserlist = 1;
 			sess = session_new (serv, name, SESS_SERVER, focus);
-			prefs.hideuserlist = oldh;
-		} else
-		{
+		else
 			sess = session_new (serv, name, SESS_CHANNEL, focus);
-		}
 		serv->server_session = sess;
 		serv->front_session = sess;
 		break;
@@ -383,6 +378,8 @@ new_ircwindow (server *serv, char *name, int type, int focus)
 	}
 
 	irc_init (sess);
+	if (prefs.text_replay)
+		scrollback_load (sess);
 	plugin_emit_dummy_print (sess, "Open Context");
 
 	return sess;
@@ -498,6 +495,7 @@ session_free (session *killsess)
 	exec_notify_kill (killsess);
 
 	log_close (killsess);
+	scrollback_close (killsess);
 
 	send_quit_or_part (killsess);
 
