@@ -266,7 +266,7 @@ notify_opendialog_clicked (GtkWidget * igad)
 	if (gtkutil_treeview_get_selected (view, &iter, NPS_COLUMN, &servnot, -1))
 	{
 		if (servnot)
-			open_query (servnot->server, servnot->notify->name);
+			open_query (servnot->server, servnot->notify->name, TRUE);
 	}
 }
 
