@@ -1,5 +1,5 @@
 /* X-Chat
- * Copyright (C) 2004-2005 Peter Zelezny.
+ * Copyright (C) 2004-2007 Peter Zelezny.
  */
 
 #include <stdio.h>
@@ -20,6 +20,7 @@
 #include "maingui.h"
 #include "palette.h"
 #include "pixmaps.h"
+#include "menu.h"
 
 #include <gtk/gtkcolorseldialog.h>
 #include <gtk/gtktable.h>
@@ -172,13 +173,35 @@ static const char *const ulmenutext[] =
 	NULL
 };
 
+static const char *const cspos[] =
+{
+	N_("Left (Upper)"),
+	N_("Left (Lower)"),
+	N_("Right (Upper)"),
+	N_("Right (Lower)"),
+	N_("Top"),
+	N_("Bottom"),
+	N_("Hidden"),
+	NULL
+};
+
+static const char *const ulpos[] =
+{
+	N_("Left (Upper)"),
+	N_("Left (Lower)"),
+	N_("Right (Upper)"),
+	N_("Right (Lower)"),
+	NULL
+};
+
 static const setting userlist_settings[] =
 {
 	{ST_HEADER,	N_("User List"),0,0,0},
 	{ST_TOGGLE, N_("Show hostnames in user list"), P_OFFINTNL(showhostname_in_userlist), 0, 0, 0},
 	{ST_TOGGLE, N_("Use the Text box font and colors"), P_OFFINTNL(style_namelistgad),0,0,0},
-	{ST_TOGGLE, N_("Resizable user list"), P_OFFINTNL(paned_userlist),0,0,0},
+/*	{ST_TOGGLE, N_("Resizable user list"), P_OFFINTNL(paned_userlist),0,0,0},*/
 	{ST_MENU,	N_("User list sorted by:"), P_OFFINTNL(userlist_sort), 0, ulmenutext, 0},
+	{ST_MENU,	N_("Show user list at:"), P_OFFINTNL(gui_ulist_pos), 0, ulpos, 1},
 
 	{ST_HEADER,	N_("Away tracking"),0,0,0},
 	{ST_TOGGLE,	N_("Track the Away status of users and mark them in a different color"), P_OFFINTNL(away_track),0,0,2},
@@ -201,16 +224,7 @@ static const char *const tabwin[] =
 	NULL
 };
 
-static const char *const tabpos[] =
-{
-	N_("Bottom"),
-	N_("Top"),
-	N_("Left"),
-	N_("Right"),
-	N_("Hidden"),
-	NULL
-};
-
+#if 0
 static const char *const focusnewtabsmenu[] =
 {
 	N_("Never"),
@@ -218,17 +232,29 @@ static const char *const focusnewtabsmenu[] =
 	N_("Only requested tabs"),
 	NULL
 };
+#endif
+
+static const char *const swtype[] =
+{
+	N_("Tabs"),	/* 0 tabs */
+	"",			/* 1 reserved */
+	N_("Tree"),	/* 2 tree */
+	NULL
+};
 
 static const setting tabs_settings[] =
 {
-	{ST_HEADER,	N_("Tabs"),0,0,0},
+	/*{ST_HEADER,	N_("Channel Switcher"),0,0,0},*/
+	{ST_RADIO,  N_("Switcher type:"),P_OFFINTNL(tab_layout), 0, swtype, 0},
 	{ST_TOGGLE, N_("Open an extra tab for server messages"), P_OFFINTNL(use_server_tab), 0, 0, 0},
 	{ST_TOGGLE, N_("Open an extra tab for server notices"), P_OFFINTNL(notices_tabs), 0, 0, 0},
 	{ST_TOGGLE, N_("Open a new tab when you receive a private message"), P_OFFINTNL(autodialog), 0, 0, 0},
 	{ST_TOGGLE, N_("Sort tabs in alphabetical order"), P_OFFINTNL(tab_sort), 0, 0, 0},
 	{ST_TOGGLE, N_("Small tabs"), P_OFFINTNL(tab_small), 0, 0, 0},
+#if 0
 	{ST_MENU,	N_("Focus new tabs:"), P_OFFINTNL(newtabstofront), 0, focusnewtabsmenu, 0},
-	{ST_MENU,	N_("Show tabs at:"), P_OFFINTNL(tabs_position), 0, tabpos, 0},
+#endif
+	{ST_MENU,	N_("Show channel switcher at:"), P_OFFINTNL(tab_pos), 0, cspos, 1},
 	{ST_NUMBER,	N_("Shorten tab labels to:"), P_OFFINTNL(truncchans), 0, (const char **)N_("letters."), 99},
 
 	{ST_HEADER,	N_("Tabs or Windows"),0,0,0},
@@ -302,7 +328,9 @@ static const setting alert_settings[] =
 	{ST_HEADER,	N_("Alerts"),0,0,0},
 
 	{ST_ALERTHEAD},
+#ifndef WIN32
 	{ST_3OGGLE, N_("Show tray balloons on:"), 0, 0, (void *)balloonlist, 0},
+#endif
 	{ST_3OGGLE, N_("Blink tray icon on:"), 0, 0, (void *)trayblinklist, 0},
 	{ST_3OGGLE, N_("Blink task bar on:"), 0, 0, (void *)taskbarlist, 0},
 	{ST_3OGGLE, N_("Make a beep sound on:"), 0, 0, (void *)beeplist, 0},
@@ -654,11 +682,41 @@ setup_create_hscale (GtkWidget *table, int row, const setting *set)
 							GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 }
 
-#if 0
+
+static GtkWidget *proxy_user; 	/* username GtkEntry */
+static GtkWidget *proxy_pass; 	/* password GtkEntry */
+
+static void
+setup_menu_cb (GtkWidget *cbox, const setting *set)
+{
+	int n = gtk_combo_box_get_active (GTK_COMBO_BOX (cbox));
+
+	/* set the prefs.<field> */
+	setup_set_int (&setup_prefs, set, n + set->extra);
+
+	if (set->list == proxytypes)
+	{
+		/* only HTTP and Socks5 can use a username/pass */
+		gtk_widget_set_sensitive (proxy_user, (n == 3 || n == 4 || n == 5));
+		gtk_widget_set_sensitive (proxy_pass, (n == 3 || n == 4 || n == 5));
+	}
+}
+
+static void
+setup_radio_cb (GtkWidget *item, const setting *set)
+{
+	if (GTK_TOGGLE_BUTTON (item)->active)
+	{
+		int n = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "n"));
+		/* set the prefs.<field> */
+		setup_set_int (&setup_prefs, set, n);
+	}
+}
+
 static int
 setup_create_radio (GtkWidget *table, int row, const setting *set)
 {
-	GtkWidget *wid;
+	GtkWidget *wid, *hbox;
 	int i;
 	const char **text = (const char **)set->list;
 	GSList *group;
@@ -668,44 +726,33 @@ setup_create_radio (GtkWidget *table, int row, const setting *set)
 	gtk_table_attach (GTK_TABLE (table), wid, 2, 3, row, row + 1,
 							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, LABEL_INDENT, 0);
 
+	hbox = gtk_hbox_new (0, 0);
+	gtk_table_attach (GTK_TABLE (table), hbox, 3, 4, row, row + 1,
+							GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+
 	i = 0;
 	group = NULL;
 	while (text[i])
 	{
-		wid = gtk_radio_button_new_with_label (group, text[i]);
-		if (set->tooltip)
-			add_tip (wid, _(set->tooltip));
-		group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (wid));
-		gtk_table_attach_defaults (GTK_TABLE (table), wid, 3, 4, row, row + 1);
-		if (i == setup_get_int (&setup_prefs, set))
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), TRUE);
+		if (text[i][0] != 0)
+		{
+			wid = gtk_radio_button_new_with_mnemonic (group, text[i]);
+			/*if (set->tooltip)
+				add_tip (wid, _(set->tooltip));*/
+			group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (wid));
+			gtk_container_add (GTK_CONTAINER (hbox), wid);
+			if (i == setup_get_int (&setup_prefs, set))
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wid), TRUE);
+			g_object_set_data (G_OBJECT (wid), "n", GINT_TO_POINTER (i));
+			g_signal_connect (G_OBJECT (wid), "toggled",
+									G_CALLBACK (setup_radio_cb), (gpointer)set);
+		}
 		i++;
 		row++;
 	}
 
 	return i;
 }
-#endif
-
-static GtkWidget *proxy_user; 	/* username GtkEntry */
-static GtkWidget *proxy_pass; 	/* password GtkEntry */
-
-
-static void
-setup_menu_cb (GtkWidget *cbox, const setting *set)
-{
-	int n = gtk_combo_box_get_active (GTK_COMBO_BOX (cbox));
-
-	/* set the prefs.<field> */
-	setup_set_int (&setup_prefs, set, n);
-
-	if (set->list == proxytypes)
-	{
-		/* only HTTP and Socks5 can use a username/pass */
-		gtk_widget_set_sensitive (proxy_user, (n == 3 || n == 4 || n == 5));
-		gtk_widget_set_sensitive (proxy_pass, (n == 3 || n == 4 || n == 5));
-	}
-}
 
 /*
 static const char *id_strings[] =
@@ -794,7 +841,7 @@ setup_create_menu (GtkWidget *table, int row, const setting *set)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (cbox), _(text[i]));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (cbox),
-									  setup_get_int (&setup_prefs, set));
+									  setup_get_int (&setup_prefs, set) - set->extra);
 	g_signal_connect (G_OBJECT (cbox), "changed",
 							G_CALLBACK (setup_menu_cb), (gpointer)set);
 
@@ -1050,11 +1097,9 @@ setup_create_page (const setting *set)
 		case ST_MENU:
 			setup_create_menu (tab, row, &set[i]);
 			break;
-#if 0
 		case ST_RADIO:
 			row += setup_create_radio (tab, row, &set[i]);
 			break;
-#endif
 		case ST_NUMBER:
 			wid = setup_create_spin (tab, row, &set[i]);
 			break;
@@ -1638,7 +1683,7 @@ static const char *const cata[] =
 		N_("Text box"),
 		N_("Input box"),
 		N_("User list"),
-		N_("Tabs"),
+		N_("Channel switcher"),
 		N_("Colors"),
 		NULL,
 	N_("Chatting"),
@@ -1849,7 +1894,7 @@ unslash (char *dir)
 }
 
 void
-setup_apply_real (int new_pix, int do_ulist)
+setup_apply_real (int new_pix, int do_ulist, int do_layout)
 {
 	GSList *list;
 	session *sess;
@@ -1901,6 +1946,9 @@ setup_apply_real (int new_pix, int do_ulist)
 
 	mg_apply_setup ();
 	tray_apply_setup ();
+
+	if (do_layout)
+		menu_change_layout ();
 }
 
 static void
@@ -1909,6 +1957,7 @@ setup_apply (struct xchatprefs *pr)
 	int new_pix = FALSE;
 	int noapply = FALSE;
 	int do_ulist = FALSE;
+	int do_layout = FALSE;
 
 	if (strcmp (pr->background, prefs.background) != 0)
 		new_pix = TRUE;
@@ -1933,12 +1982,14 @@ setup_apply (struct xchatprefs *pr)
 		noapply = TRUE;
 	if (DIFF (truncchans))
 		noapply = TRUE;
+	if (DIFF (tab_layout))
+		do_layout = TRUE;
 
 	if (color_change || (DIFF (away_size_max)) || (DIFF (away_track)))
 		do_ulist = TRUE;
 
-	if (pr->tabs_position < 2 && pr->tabs_position != 4 &&
-		 pr->tab_layout == 2 && pr->tabs_position != prefs.tabs_position)
+	if ((pr->tab_pos == 5 || pr->tab_pos == 6) &&
+		 pr->tab_layout == 2 && pr->tab_pos != prefs.tab_pos)
 		fe_message (_("You cannot place the tree on the top or bottom!\n"
 						"Please change to the <b>Tabs</b> layout in the <b>View</b>"
 						" menu first."),
@@ -1946,7 +1997,7 @@ setup_apply (struct xchatprefs *pr)
 
 	memcpy (&prefs, pr, sizeof (prefs));
 
-	setup_apply_real (new_pix, do_ulist);
+	setup_apply_real (new_pix, do_ulist, do_layout);
 
 	if (noapply)
 		fe_message (_("Some settings were changed that require a"
